# API

## Preprocessing

```{eval-rst}
.. module:: dummy_anndata.pp
.. currentmodule:: dummy_anndata

.. autosummary::
    :toctree: generated

    pp.basic_preproc
```

## Tools

```{eval-rst}
.. module:: dummy_anndata.tl
.. currentmodule:: dummy_anndata

.. autosummary::
    :toctree: generated

    tl.basic_tool
```

## Plotting

```{eval-rst}
.. module:: dummy_anndata.pl
.. currentmodule:: dummy_anndata

.. autosummary::
    :toctree: generated

    pl.basic_plot
    pl.BasicClass
```
